==> library1.4.1.tar.bz2: library/zal/editform.php <==
<?php
///////////////////////////////////////////////////
//2009 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['zal-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  $button = $TEXT['btn_save'];
  $action = "edit.php";

  if(strlen($_GET['zal_id'])>5) {puterror($result2['skin'],$TEXT['error-zal6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['zal_id'] = rep($_GET['zal_id']);
  
  $old_zal_id = $_GET['zal_id'];

  $query10 = "SELECT * FROM `tbl_zal` WHERE `zal_id`='".$_GET['zal_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl11']); require_once "../utils/bottom_adm.php"; exit();}
      $result_zal = mysqli_fetch_array($result10);
         $zal = $result_zal['zal'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="bold_it"><?php echo $TEXT['global-edit']; ?></td><td class="bold_it"><input size=30 maxlength=127 class="input" type=text name=zal value='<?php echo $zal; ?>'></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>'></td></tr>
<input type=hidden name=zal_id value='<?php echo $old_zal_id; ?>'>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/zal/editform.php <==
<?php
///////////////////////////////////////////////////
//2009 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['zal-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  $button = $TEXT['btn_save'];
  $action = "edit.php";

  if(strlen($_GET['zal_id'])>5) {puterror($result2['skin'],$TEXT['error-zal6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['zal_id'] = rep($_GET['zal_id']);
  
  $old_zal_id = $_GET['zal_id'];

  $query10 = "SELECT * FROM `tbl_zal` WHERE `zal_id`='".$_GET['zal_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl11']); require_once "../utils/bottom_adm.php"; exit();}
      $result_zal = mysqli_fetch_array($result10);
         $zal = rep_back($result_zal['zal']);
?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center">
<tr><td class="bold_it"><?php echo $TEXT['global-edit']; ?></td><td class="bold_it"><input size="30" maxlength="127" type="text" name="zal" value="<?php echo $zal; ?>" /></td></tr>
<tr><td></td><td><input class="button2" type="submit" value="<?php echo $button; ?>" /></td></tr>
<input type="hidden" name="zal_id" value="<?php echo $old_zal_id; ?>" />
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>
